@@ -91,7 +91,7 @@
  */
 
 #define	MAXOBJ	512
-static void obm_call_activate_callbacks();
+static void obm_call_activate_callbacks(struct obmContext *obm, int state);
 
 
 #if (TCL_MAJOR_VERSION < 8)
@@ -104,16 +104,13 @@ static void obm_call_activate_callbacks();
  */
 #if (TCL_MAJOR_VERSION == 8) && (TCL_MINOR_VERSION < 6)
 int
-Tcl_GetErrorLine(tcl)
-Tcl_Interp *tcl;
+Tcl_GetErrorLine(Tcl_Interp *tcl)
 {
 	return tcl->errorLine;
 }
 
 void
-Tcl_SetErrorLine(tcl, lineNum)
-Tcl_Interp *tcl;
-int lineNum;
+Tcl_SetErrorLine(Tcl_Interp *tcl, int lineNum)
 {
 	tcl->errorLine = lineNum;
 }
@@ -123,14 +120,11 @@ int lineNum;
 /* ObmOpen -- Open the object manager.
  */
 ObmContext
-ObmOpen (app_context, argc, argv)
-XtAppContext app_context;
-int argc;
-char *argv[];
+ObmOpen (XtAppContext app_context, int argc, char *argv[])
 {
-	register ObmContext obm;
-	register ObjClassRec classrec;
-	register int i;
+	ObmContext obm;
+	ObjClassRec classrec;
+	int i;
 	char *s;
 
 	/* Initialize object manager global context. */
@@ -167,11 +161,10 @@ char *argv[];
 /* ObmClose -- Close the object manager.
  */
 void
-ObmClose (obm)
-ObmContext obm;
+ObmClose (ObmContext obm)
 {
-	register ObjClassRec classrec;
-	register int i;
+	ObjClassRec classrec;
+	int i;
 
 	/* Get rid of any current UI. */
 	ObmInitialize (obm);
@@ -198,12 +191,11 @@ ObmContext obm;
  * user interface.
  */
 void
-ObmInitialize (obm)
-register ObmContext obm;
+ObmInitialize (ObmContext obm)
 {
-	register ObmObject obj, nextobj;
-	register ObmCallback cb;
-	register MenuItem ip;
+	ObmObject obj, nextobj;
+	ObmCallback cb;
+	MenuItem ip;
 	ObjList lp, lp_next;
 	Menu mp;
 	int i;
@@ -287,10 +279,9 @@ register ObmContext obm;
  * such a state as to be ready for client i/o.
  */
 void
-ObmActivate (obm)
-register ObmContext obm;
+ObmActivate (ObmContext obm)
 {
-	register ObmObject obj;
+	ObmObject obj;
 	char defaultUI[SZ_MESSAGE];
 
 	/* UI has already been activated? */
@@ -341,13 +332,10 @@ register ObmContext obm;
  * was deactivated.
  */
 void
-ObmDeactivate (obm, unmap)
-register ObmContext obm;
-Boolean unmap;
+ObmDeactivate (ObmContext obm, Boolean unmap)
 {
-	register ObmObject obj;
-	register ObmCallback cb;
-	ObmFunc deactivate;
+	ObmObject obj;
+	ObmCallback cb;
 
 	/* The Obm "activated" flag is not affected by deactivation.
 	 * Deactivation merely means that control has temporarily been
@@ -374,12 +362,10 @@ Boolean unmap;
  * lists and call any activate/deactivate callbacks.
  */
 static void
-obm_call_activate_callbacks (obm, state)
-register ObmContext obm;
-int state;
+obm_call_activate_callbacks (ObmContext obm, int state)
 {
-	register ObmCallback cb;
-	register int type;
+	ObmCallback cb;
+	int type;
 
 	/* Call any client activate callbacks. */
 	type = state ? OBMCB_activate : OBMCB_deactivate;
@@ -414,8 +400,7 @@ int state;
  * and mapped.
  */
 int
-ObmActivated (obm)
-register ObmContext obm;
+ObmActivated (ObmContext obm)
 {
 	return (obm->activated && obm->mapped);
 }
@@ -424,10 +409,7 @@ register ObmContext obm;
 /* ObmStatus -- Get the Object Manager status.
  */
 int
-ObmStatus (obm, app_name, app_class)
-register ObmContext obm;
-char *app_name;
-char *app_class;
+ObmStatus (ObmContext obm, char *app_name, char *app_class)
 {
 	if (obm->specified) {
 	    if (app_name)
@@ -448,8 +430,7 @@ char *app_class;
  * by the GUI code.
  */
 XtPointer
-ObmGetInterp (obm)
-register ObmContext obm;
+ObmGetInterp (ObmContext obm)
 {
 	return ((XtPointer)obm->tcl);
 }
@@ -458,13 +439,10 @@ register ObmContext obm;
 /* ObmDeliverMsg -- Deliver a message to a UI object.
  */
 int
-ObmDeliverMsg (obm, object, message)
-register ObmContext obm;
-char *object;
-char *message;
+ObmDeliverMsg (ObmContext obm, const char *object, const char *message)
 {
-	register ObmFunc evaluate;
-	register ObmObject obj;
+	ObmEvaluateFunc evaluate;
+	ObmObject obj;
 	int status = TCL_ERROR;
 
 	if (obm->debug) {
@@ -506,10 +484,7 @@ char *message;
  * message from the named text file.
  */
 int
-ObmDeliverMsgFromFile (obm, object, fname)
-register ObmContext obm;
-char *object;
-char *fname;
+ObmDeliverMsgFromFile (ObmContext obm, char *object, char *fname)
 {
 	struct stat fs;
 	char *message = NULL;
@@ -546,13 +521,9 @@ err:
  * callback list.
  */
 void
-ObmAddCallback (obm, callback_type, fcn, client_data)
-register ObmContext obm;
-int callback_type;
-ObmFunc fcn;
-XtPointer client_data;
+ObmAddCallback (ObmContext obm, int callback_type, ObmFunc fcn, XtPointer client_data)
 {
-	register ObmCallback cb;
+	ObmCallback cb;
 
 	if (!(cb = obmAddCallback (&obm->callback_list)))
 	    return;
@@ -567,9 +538,7 @@ XtPointer client_data;
 /* ObmRemoveCallback -- Remove a callback from the OBM global callback list.
  */
 void
-ObmRemoveCallback (obm, callback)
-register ObmContext obm;
-ObmCallback callback;
+ObmRemoveCallback (ObmContext obm, ObmCallback callback)
 {
 	obmRemoveCallback (&obm->callback_list, callback);
 }
@@ -586,12 +555,11 @@ ObmCallback callback;
  * may be given to specify which object to use.
  */
 ObmObject
-obmFindObject (obm, object)
-ObmContext obm;
-char *object;
+obmFindObject (ObmContext obm, const char *object)
 {
-	register int hashval, n;
-	register char *ip, *op;
+	int hashval, n;
+	const char *ip;
+	char *op;
 	ObmObject objlist1[MAXOBJ], objlist2[MAXOBJ];
 	ObmObject obj, *otemp, *objs, *pobjs;
 	char name[SZ_NAME];
@@ -643,16 +611,16 @@ char *object;
  * is returned.
  */
 int
-obm_nameToObjectList (obm, object, pobjs, nobjs, objs)
-ObmContext obm;
-char *object;			/* object name */
-ObmObject *pobjs;		/* list of parent objects */
-int *nobjs;			/* number of objects found (output) */
-ObmObject *objs;		/* list of objects (output) */
+obm_nameToObjectList (
+  ObmContext obm,
+  char *object,			/* object name */
+  ObmObject *pobjs,		/* list of parent objects */
+  int *nobjs,			/* number of objects found (output) */
+  ObmObject *objs)		/* list of objects (output) */
 {
-	register char *ip;
-	register int hashval, n;
-	register ObmObject obj;
+	char *ip;
+	int hashval, n;
+	ObmObject obj;
 	int accept, i;
 
 	if (object == NULL)
@@ -691,16 +659,16 @@ ObmObject *objs;		/* list of objects (output) */
 /* obmNewObject -- Create a new object of the given type.
  */
 void
-obmNewObject (obm, name, class, parent, args, nargs)
-register ObmContext obm;
-char *name;			/* name of new object */
-char *class;			/* name of class to which object belongs */
-char *parent;			/* name of parent widget, for widget objects */
-ArgList args;			/* optional argument list */
-int nargs;			/* optional argument list */
+obmNewObject (
+  ObmContext obm,
+  const char *name,		/* name of new object */
+  const char *class,		/* name of class to which object belongs */
+  const char *parent,		/* name of parent widget, for widget objects */
+  ArgList args,			/* optional argument list */
+  int nargs)			/* optional argument list */
 {
-	register char *ip;
-	register int hashval, n;
+	const char *ip;
+	int hashval, n;
 	ObmObject newobj, obj, pobj;
 	ObjClassRec classrec;
 
@@ -778,13 +746,11 @@ int nargs;			/* optional argument list */
 /* obmDestroyObject -- Destroy an object and all its descendents.
  */
 void
-obmDestroyObject (obm, object)
-ObmContext obm;
-ObmObject object;
+obmDestroyObject (ObmContext obm, ObmObject object)
 {
-	register ObmObjectCore cp = &object->core;
-	register ObmObject obj;
-	register int i;
+	ObmObjectCore cp = &object->core;
+	ObmObject obj;
+	int i;
 	int hashval, n;
 	char *ip;
 
@@ -881,13 +847,11 @@ ObmObject object;
  * shells.
  */
 void
-obmDisplay (obm, obj)
-ObmContext obm;
-ObmObject obj;
+obmDisplay (ObmContext obm, ObmObject obj)
 {
-	register Widget w = widgetGetPointer (obj);
-	register ObmObject child;
-	register int i;
+	Widget w = widgetGetPointer (obj);
+	ObmObject child;
+	int i;
 	char buf[SZ_NAME];
 
 	for (i=0;  i < obj->core.nchildren;  i++) {
@@ -910,13 +874,11 @@ ObmObject obj;
  * shells.
  */
 void
-obmUndisplay (obm, obj)
-ObmContext obm;
-ObmObject obj;
+obmUndisplay (ObmContext obm, ObmObject obj)
 {
-	register int i;
-	register ObmObject child;
-	register Widget w = widgetGetPointer (obj);
+	int i;
+	ObmObject child;
+	Widget w = widgetGetPointer (obj);
 	XWindowAttributes wa;
 	char *s;
 
@@ -947,11 +909,10 @@ ObmObject obj;
 /* obmGetClassrec -- Get the class record for the named class.
  */
 ObjClassRec
-obmGetClassrec (classname)
-char *classname;
+obmGetClassrec (const char *classname)
 {
-	register ObjClassRec classrec;
-	register int i;
+	ObjClassRec classrec;
+	int i;
 
 	for (i=0;  i < XtNumber(UiObjects);  i++) {
 	    classrec = &UiObjects[i];
@@ -966,9 +927,7 @@ char *classname;
 /* obmGenericClassDestroy - Free any resources associated with a class record.
  */
 void
-obmGenericClassDestroy (obm, classrec)
-ObmContext obm;
-register ObjClassRec classrec;
+obmGenericClassDestroy (ObmContext obm, ObjClassRec classrec)
 {
 }
 
@@ -976,9 +935,7 @@ register ObjClassRec classrec;
 /* obmClass -- Test if a class record belongs to the given object class.
  */
 int
-obmClass (classrec, flag1, flag2)
-register ObjClassRec classrec;
-unsigned long flag1, flag2;
+obmClass (ObjClassRec classrec, unsigned long flag1, unsigned long flag2)
 {
 	return ((classrec->flag1 & flag1) || (classrec->flag2 & flag2));
 }
@@ -987,10 +944,9 @@ unsigned long flag1, flag2;
 /* obmAddCallback -- Add a callback descriptor to a callback list.
  */
 ObmCallback
-obmAddCallback (callback_list)
-ObmCallback *callback_list;
+obmAddCallback (ObmCallback *callback_list)
 {
-	register ObmCallback cb, last_cb;
+	ObmCallback cb, last_cb;
 
 	/* Find tail of list. */
 	for (cb = last_cb = *callback_list;  cb;  cb = cb->next)
@@ -1011,11 +967,9 @@ ObmCallback *callback_list;
 /* obmRemoveCallback -- Remove a callback descriptor from a callback list.
  */
 void
-obmRemoveCallback (callback_list, callback)
-ObmCallback *callback_list;
-ObmCallback callback;
+obmRemoveCallback (ObmCallback *callback_list, ObmCallback callback)
 {
-	register ObmCallback cb, last_cb;
+	ObmCallback cb, last_cb;
 
 	if (!callback)
 	    return;
@@ -1041,11 +995,10 @@ ObmCallback callback;
  * the given Tcl interepter.
  */
 int
-obmClientCommand (tcl, commmand)
-Tcl_Interp *tcl;
-char *commmand;
+obmClientCommand (Tcl_Interp *tcl, const char *commmand)
 {
-	register char *ip, *op;
+	const char *ip;
+	char *op;
 	char name[SZ_NAME];
 	Tcl_CmdInfo info;
 
