@@ -1,5 +1,7 @@
 
 #include <stdint.h>
+#include <strings.h>
+
 /* Convenience macros.
 */
 #define	GPMtoRPM		gtermPM_to_rasPM	/* Pixmap	*/
@@ -61,6 +63,7 @@ Pixmap rasPM_to_rasPM (Raster src, Raster dest)
 	fprintf (stderr, "RPMtoRPM: %d > %d\n", src->depth, dest->depth);
 	return 0; /* not implemented yet */
     }
+    return 0;
 }
 
 
@@ -87,6 +90,7 @@ Pixmap rasPM_to_gtermPM (Raster src, GtermWidget w)
 	fprintf (stderr, "RPMtoRPM: %d > %d\n", src->depth, w->gterm.w_depth);
 	return 0; /* not implemented yet */
     }
+    return 0;
 }
 
 
@@ -99,12 +103,12 @@ Pixmap rasPM_to_gtermPM (Raster src, GtermWidget w)
 XImage *ximage_to_rasPM (GtermWidget w, XImage *xin, Raster dest, 
   	    int sx, int sy, int dnx, int dny)
 {
-    uchar *renderPixels ();
+    uchar *renderPixels (GtermWidget w, uchar *in, int width, int height, int depth, int sx, int sy, int dnx, int dny, int bpl, int bpp, int border);
     XImage *cnvImg  = (XImage *) NULL;
 
  
     if (DBG_TRACE) {
-	fprintf (stderr, "IMGtoRPM: %d <-> %d  [%d,%d]  cnvImg=0x%x\n",
+	fprintf (stderr, "IMGtoRPM: %d <-> %d  [%d,%d]  cnvImg=%p\n",
 	    xin->depth, dest->depth, xin->width, xin->height, cnvImg);
 	fprintf (stderr, "IMGtoRPM: Map: (%d,%d)  : %d  %d\n",
 	    sx, sy, dnx, dny);
@@ -145,7 +149,7 @@ XImage *ximage_to_rasPM (GtermWidget w, XImage *xin, Raster dest,
 XImage *ximage_to_gtermPM (GtermWidget w, XImage *xin, 
   	    int sx, int sy, int dnx, int dny)
 {
-    uchar *renderPixels ();
+    uchar *renderPixels (GtermWidget w, uchar *in, int width, int height, int depth, int sx, int sy, int dnx, int dny, int bpl, int bpp, int border);
     XImage *cnvImg  = (XImage *) NULL;
 
  
@@ -191,14 +195,9 @@ XImage *ximage_to_gtermPM (GtermWidget w, XImage *xin,
 **  the pointer to the output pixels and assume the caller will free it.
 */
 uchar *
-renderPixels (w, in, width, height, depth, sx, sy, dnx, dny, bpl, bpp, border)
-GtermWidget w;
-uchar	*in;
-int	width, height, depth;
-int	sx, sy, dnx, dny;
-int     bpl, bpp, border;
+renderPixels (GtermWidget w, uchar *in, int width, int height, int depth, int sx, int sy, int dnx, int dny, int bpl, int bpp, int border)
 {
-    register int i, j, npix = (width * height);
+    int i, j, npix = (width * height);
     uint32_t  *lp, xcol, lval;
     int    nbytes = ((depth == ColormapDepth) ? 1 : 4);
     uchar  *ip = in, pv;
@@ -258,7 +257,7 @@ int     bpl, bpp, border;
 static int
 init_lut (int bpp, int border)
 {
-    register int i;
+    int i;
     unsigned long  rmask, gmask, bmask, rpix, gpix, bpix, xcol, lval;
     int    rshift, gshift, bshift, nbytes;
     uchar  *op, pv;
@@ -336,7 +335,7 @@ init_lut (int bpp, int border)
     }
 
     if (DBG_TRACE && DBG_CM_VERB)
-	fprintf (stderr, "init_lut: mask=(0x%x,0x%x,0x%x) shift=(%d,%d,%d)\n",
+	fprintf (stderr, "init_lut: mask=(0x%lx,0x%lx,0x%lx) shift=(%d,%d,%d)\n",
 	    rmask, gmask, bmask, rshift, gshift, bshift);
 
     valid_lut = 1;
@@ -350,7 +349,7 @@ init_lut (int bpp, int border)
 */
 int highbit(unsigned long i)
 {
-    register int h = 1;
+    int h = 1;
     if (i == 0)
         return (0);
 #ifdef _LP64
@@ -372,7 +371,7 @@ int highbit(unsigned long i)
 */
 int lowbit(unsigned long i)
 {
-    register int h = 1;
+    int h = 1;
 
     if (i == 0)
         return (0);
@@ -416,7 +415,7 @@ dbg_printCmaps (GtermWidget w)
 
     fprintf (stderr, "cmaps: first=%d nelem=%d max=%d  nc=%d\n",
         first, nelem, maxelem, nc);
-    fprintf (stderr, "cmaps: basePixel=%d  maxColors=%d ncolors=%d\n",
+    fprintf (stderr, "cmaps: basePixel=%lu  maxColors=%d ncolors=%d\n",
         w->gterm.base_pixel, w->gterm.maxColors, w->gterm.ncolors);
 
 
@@ -433,7 +432,7 @@ dbg_printCmaps (GtermWidget w)
     fprintf (stderr, "GlobalCmap   cm    in   out\n");
     for (i=0;  i < MAX_SZCMAP;  i++)
      fprintf (stderr, 
-     "cmap: %3d  %3d   %3d %3d %3d   %3d %3d %3d  %3d %3d %3d  %3d  %3d  %3d\n",
+     "cmap: %3d  %3d   %3d %3d %3d   %3d %3d %3d  %3d %3d %3d  %3lu  %3lu  %3lu\n",
           i, iomap[i], rs[i]>>8, gs[i]>>8, bs[i]>>8, r[i], g[i], b[i],
 	  global_color[i].red>>8, global_color[i].green>>8, 
 	  global_color[i].blue>>8, global_cmap[i],
@@ -466,7 +465,7 @@ dbg_printMappings (GtermWidget w)
 static void
 dbg_printRasters (GtermWidget w)
 {
-    register int i;
+    int i;
     Raster   rp;
 
 
@@ -476,7 +475,7 @@ dbg_printRasters (GtermWidget w)
 	fprintf (stderr, "Raster %d:  ty=%s  size=(%d,%d,%d)\t",
 	    i, (rp->type == 1 ? "ximage" : "pixmap"),
 	    rp->width, rp->height, rp->depth);
-	fprintf (stderr, ": p=0x%x im=0x%x sh=0x%x\n",
+	fprintf (stderr, ": p=0x%lx im=%p sh=0x%lx\n",
 	    rp->r.pixmap, rp->r.ximage, rp->shadow_pixmap);
     }
 }
