@@ -48,9 +48,6 @@
 #define	NColors			8
 
 typedef void (*GmVMethod)();
-typedef int  (*GmIMethod)();
-#define uchar	unsigned char
-#define ushort	unsigned short
 
 /* Raster definitions. */
 #define	ImageRaster		1
@@ -296,7 +293,6 @@ typedef struct markerSelection *GmSelection;
 
 /* Gterm callbacks.
 */
-typedef void (*GtCallbackProc)();
 struct gtCallback {
 	GtCallbackProc proc;
 	XtPointer client_data;
@@ -435,7 +431,7 @@ typedef struct {
 	Pixel		*cmap;			/* map color number to pixval */
 	XColor		*color;			/* RGB color assignments      */
 
-	ushort		iomap[MAX_SZCMAP];	/* client i/o color map       */
+	unsigned short	iomap[MAX_SZCMAP];	/* client i/o color map       */
 	Pixel		cmap_in[MAX_SZCMAP];	/* umap and cmap combined     */
 	Pixel		cmap_out[MAX_SZCMAP];	/* umap and cmap combined     */
 	int		cmap_in_valid;		/* set when cmap_in computed  */
