@@ -4,11 +4,7 @@ static XImage *cached_ximage =	NULL;			/* MF004 BEGIN */
 /* GetCachedXImage -- 
  */
 static XImage *
-GetCachedXImage (w, pixmap, width, height)
-     GtermWidget w;
-     Pixmap pixmap;
-     int width;
-     int height;
+GetCachedXImage (GtermWidget w, Pixmap pixmap, int width, int height)
 {
     if ((cached_ximage != NULL)) {
         if ((pixmap == w->gterm.pixmap) &&
@@ -24,7 +20,7 @@ GetCachedXImage (w, pixmap, width, height)
 /* DestroyCachedXImage --
  */
 static void 
-DestroyCachedXImage ()
+DestroyCachedXImage (void)
 {
     if (cached_ximage != NULL) {
         XDestroyImage (cached_ximage);
@@ -36,12 +32,7 @@ DestroyCachedXImage ()
 /* NewCachedXImage --
  */
 static void 
-NewCachedXImage (w, xin, pixmap, width, height)
-     GtermWidget w;
-     XImage *xin;
-     Pixmap pixmap;
-     int width;
-     int height;
+NewCachedXImage (GtermWidget w, XImage *xin, Pixmap pixmap, int width, int height)
 {
     if ((pixmap ==  w->gterm.pixmap) &&
         (width  ==  w->core.width)   &&
