@@ -2,8 +2,6 @@
  *	Functions for drawing String's with tab characters in them
  */
 
-#if (NeedFunctionPrototypes > 0)
-
 extern void	XfwfDrawImageString(Display *display, Drawable drawable,
 			GC gc, int x, int y, String string, int length,
 			int *tabs);
@@ -17,15 +15,3 @@ extern int *	XfwfTablist2Tabs(char *tablist);
 extern int	XfwfTextWidth(XFontStruct *font, String str, int length,
 			int *tabs);
 extern char *	strnchr(char *s, int c, int n);
-
-#else
-
-extern void	XfwfDrawImageString();
-extern void	XfwfDrawString();
-extern void	XtabDrawString();
-extern int *	XfwfTablist2Tabs();
-extern int	XfwfTextWidth();
-extern char *	strnchr();
-
-#endif
-
