@@ -10,14 +10,10 @@
  *	counterpart.
  */
 int
-XfwfTextWidth(font, str, length, tabs)
-     XFontStruct *font;
-     String str;
-     int length;
-     int *tabs;
+XfwfTextWidth(XFontStruct *font, String str, int length, int *tabs)
 {
-	register char	*p, *ep;
-	register int	tx, tab, rc;
+	char	*p, *ep;
+	int	tx, tab, rc;
 
 	tab = tx = 0;
  	if (length == 0) return 0;
