@@ -1,6 +1,7 @@
 /* Copyright(c) 1993 Association of Universities for Research in Astronomy Inc.
  */
 
+#include <stdlib.h>
 #include "ObmP.h"
 #include "widget.h"
 
@@ -88,41 +89,51 @@ typedef struct {
 } htmlClassData, *HTMLClassData;
 
 
-void HTMLDestroy();
-void HTMLClassDestroy();
-ObmObject HTMLCreate();
+void HTMLDestroy(ObmObject);
+void HTMLClassDestroy(ObmContext, ObjClassRec);
+ObmObject HTMLCreate(ObmContext, const char *, ObjClassRec, const char *, ArgList, int);
 
-static int htmlSetText(), htmlGetText(), htmlGetHRefs();
-static int htmlGetImageSrcs(), htmlGetLinks();
-static int htmlRetestAnchors(), htmlPositionToId(), htmlIdToPosition();
-static int htmlAnchorToPosition(), htmlAnchorToId();
-static int htmlGotoId(), htmlAddCallback(), htmlDeleteCallback();
-static int htmlSetSelection(), htmlGetSelection(), htmlClearSelection();
-static int htmlSearchText();
+static int htmlSetText(MsgContext, Tcl_Interp *, int, char **);
+static	int htmlGetText(MsgContext, Tcl_Interp *, int, char **);
+static	int htmlGetHRefs(MsgContext, Tcl_Interp *, int, char **);
+static int htmlGetImageSrcs(MsgContext, Tcl_Interp *, int, char **);
+static	int htmlGetLinks(MsgContext, Tcl_Interp *, int, char **);
+static int htmlRetestAnchors(MsgContext, Tcl_Interp *, int, char **);
+static	int htmlPositionToId(MsgContext, Tcl_Interp *, int, char **);
+static	int htmlIdToPosition(MsgContext, Tcl_Interp *, int, char **);
+static int htmlAnchorToPosition(MsgContext, Tcl_Interp *, int, char **);
+static	int htmlAnchorToId(MsgContext, Tcl_Interp *, int, char **);
+static int htmlGotoId(MsgContext, Tcl_Interp *, int, char **);
+static	int htmlAddCallback(MsgContext, Tcl_Interp *, int, char **);
+static	int htmlDeleteCallback(MsgContext, Tcl_Interp *, int, char **);
+static int htmlSetSelection(MsgContext, Tcl_Interp *, int, char **);
+static	int htmlGetSelection(MsgContext, Tcl_Interp *, int, char **);
+static	int htmlClearSelection(MsgContext, Tcl_Interp *, int, char **);
+static int htmlSearchText(MsgContext, Tcl_Interp *, int, char **);
 
-static void anchorCallback(), pointerMotionCallback();
-static void submitFormCallback(), linkCallback();
-static char *cb_encode(), *makeList();
-static int testAnchorCallback();
-static void cb_error();
-static int cb_decode();
-extern long strtol();
+static void anchorCallback(Widget, XtPointer, XtPointer);
+static void pointerMotionCallback(Widget, XtPointer, char *);
+static void submitFormCallback(Widget, XtPointer, XtPointer);
+static void linkCallback(Widget, XtPointer, XtPointer);
+static char *cb_encode(int);
+static char *makeList(char **, int);
+static int testAnchorCallback(Widget, XtPointer, char *);
+static void cb_error(ObmContext, ObmCallback);
+static int cb_decode(char *);
 
 
 /* HTMLClassInit -- Initialize the class record for the HTML widget class.
  */
 void
-HTMLClassInit (obm, classrec)
-ObmContext obm;
-register ObjClassRec classrec;
+HTMLClassInit (ObmContext obm, ObjClassRec classrec)
 {
-	register HTMLClassData gcd;
-	register Tcl_Interp *tcl;
-	register ClientData c_gcd;
+	HTMLClassData gcd;
+	Tcl_Interp *tcl;
+	ClientData c_gcd;
 
 	/* Install the class methods. */
 	classrec->ClassDestroy = HTMLClassDestroy;
-	classrec->Create = (ObmFunc) HTMLCreate;
+	classrec->Create = HTMLCreate;
 	classrec->Destroy = HTMLDestroy;
 	classrec->Evaluate = WidgetEvaluate;
 
@@ -139,39 +150,39 @@ register ObjClassRec classrec;
 	    gcd->level = 0;
 
 	    Tcl_CreateCommand (tcl,
-		"addCallback", htmlAddCallback, c_gcd, NULL);
+		"addCallback", (Tcl_CmdProc *) htmlAddCallback, c_gcd, NULL);
 	    Tcl_CreateCommand (tcl,
-		"deleteCallback", htmlDeleteCallback, c_gcd, NULL);
+		"deleteCallback", (Tcl_CmdProc *) htmlDeleteCallback, c_gcd, NULL);
 	    Tcl_CreateCommand (tcl,
-		"setText", htmlSetText, c_gcd, NULL);
+		"setText", (Tcl_CmdProc *) htmlSetText, c_gcd, NULL);
 	    Tcl_CreateCommand (tcl,
-		"getText", htmlGetText, c_gcd, NULL);
+		"getText", (Tcl_CmdProc *) htmlGetText, c_gcd, NULL);
 	    Tcl_CreateCommand (tcl,
-		"positionToId", htmlPositionToId, c_gcd, NULL);
+		"positionToId", (Tcl_CmdProc *) htmlPositionToId, c_gcd, NULL);
 	    Tcl_CreateCommand (tcl,
-		"idToPosition", htmlIdToPosition, c_gcd, NULL);
+		"idToPosition", (Tcl_CmdProc *) htmlIdToPosition, c_gcd, NULL);
 	    Tcl_CreateCommand (tcl,
-		"anchorToPosition", htmlAnchorToPosition, c_gcd, NULL);
+		"anchorToPosition", (Tcl_CmdProc *) htmlAnchorToPosition, c_gcd, NULL);
 	    Tcl_CreateCommand (tcl,
-		"anchorToId", htmlAnchorToId, c_gcd, NULL);
+		"anchorToId", (Tcl_CmdProc *) htmlAnchorToId, c_gcd, NULL);
 	    Tcl_CreateCommand (tcl,
-		"gotoId", htmlGotoId, c_gcd, NULL);
+		"gotoId", (Tcl_CmdProc *) htmlGotoId, c_gcd, NULL);
 	    Tcl_CreateCommand (tcl,
-		"getHRefs", htmlGetHRefs, c_gcd, NULL);
+		"getHRefs", (Tcl_CmdProc *) htmlGetHRefs, c_gcd, NULL);
 	    Tcl_CreateCommand (tcl,
-		"getImageSrcs", htmlGetImageSrcs, c_gcd, NULL);
+		"getImageSrcs", (Tcl_CmdProc *) htmlGetImageSrcs, c_gcd, NULL);
 	    Tcl_CreateCommand (tcl,
-		"getLinks", htmlGetLinks, c_gcd, NULL);
+		"getLinks", (Tcl_CmdProc *) htmlGetLinks, c_gcd, NULL);
 	    Tcl_CreateCommand (tcl,
-		"retestAnchors", htmlRetestAnchors, c_gcd, NULL);
+		"retestAnchors", (Tcl_CmdProc *) htmlRetestAnchors, c_gcd, NULL);
 	    Tcl_CreateCommand (tcl,
-		"setSelection", htmlSetSelection, c_gcd, NULL);
+		"setSelection", (Tcl_CmdProc *) htmlSetSelection, c_gcd, NULL);
 	    Tcl_CreateCommand (tcl,
-		"getSelection", htmlGetSelection, c_gcd, NULL);
+		"getSelection", (Tcl_CmdProc *) htmlGetSelection, c_gcd, NULL);
 	    Tcl_CreateCommand (tcl,
-		"clearSelection", htmlClearSelection, c_gcd, NULL);
+		"clearSelection", (Tcl_CmdProc *) htmlClearSelection, c_gcd, NULL);
 	    Tcl_CreateCommand (tcl,
-		"searchText", htmlSearchText, c_gcd, NULL);
+		"searchText", (Tcl_CmdProc *) htmlSearchText, c_gcd, NULL);
 	}
 }
 
@@ -179,11 +190,9 @@ register ObjClassRec classrec;
 /* HTMLClassDestroy -- Custom destroy procedure for the HTML class.
  */
 void
-HTMLClassDestroy (obm, classrec)
-ObmContext obm;
-register ObjClassRec classrec;
+HTMLClassDestroy (ObmContext obm, ObjClassRec classrec)
 {
-	register HTMLClassData gcd = (HTMLClassData) classrec->class_data;
+	HTMLClassData gcd = (HTMLClassData) classrec->class_data;
 
 	if (gcd) {
 	    if (gcd->tcl)
@@ -197,16 +206,16 @@ register ObjClassRec classrec;
 /* HTMLCreate -- Create an instance of a HTML object.
  */
 ObmObject
-HTMLCreate (obm, name, classrec, parent, a_args, a_nargs)
-ObmContext obm;
-char *name;
-ObjClassRec classrec;
-char *parent;
-ArgList a_args;
-int a_nargs;
+HTMLCreate (
+  ObmContext obm,
+  const char *name,
+  ObjClassRec classrec,
+  const char *parent,
+  ArgList a_args,
+  int a_nargs)
 {
-	register HTMLObject obj;
-	register Widget w;
+	HTMLObject obj;
+	Widget w;
 	Arg args[128];
 	int nargs = 0;
 
@@ -246,13 +255,12 @@ int a_nargs;
 /* HTMLDestroy -- Destroy an instance of a HTML object.
  */
 void
-HTMLDestroy (object)
-ObmObject object;
+HTMLDestroy (ObmObject object)
 {
 	HTMLObject obj = (HTMLObject) object;
 	ObjClassRec classrec = obj->core.classrec;
-	register HTMLClassData gcd = (HTMLClassData) classrec->class_data;
-	register ObmCallback cb, cb_next;
+	HTMLClassData gcd = (HTMLClassData) classrec->class_data;
+	ObmCallback cb, cb_next;
 	ObmContext obm = obj->widget.obm;
 	Widget w = obj->widget.w;
 
@@ -288,15 +296,11 @@ ObmObject object;
  * this will be displayed before or after the document passed in as "text".
  */
 static int 
-htmlSetText (msg, tcl, argc, argv)
-MsgContext msg;
-Tcl_Interp *tcl;
-int argc;
-char **argv;
+htmlSetText (MsgContext msg, Tcl_Interp *tcl, int argc, char **argv)
 {
-	register HTMLClassData gcd = (HTMLClassData) msg;
+	HTMLClassData gcd = (HTMLClassData) msg;
 	HTMLObject obj = (HTMLObject) gcd->object[gcd->level];
-	register WidgetPrivate wp = &obj->widget;
+	WidgetPrivate wp = &obj->widget;
 	ObmContext obm = wp->obm;
 	char *text, *target_anchor;
 	char *header_text, *footer_text;
@@ -337,15 +341,11 @@ char **argv;
  * The default Postscript font is Times.
  */
 static int 
-htmlGetText (msg, tcl, argc, argv)
-MsgContext msg;
-Tcl_Interp *tcl;
-int argc;
-char **argv;
+htmlGetText (MsgContext msg, Tcl_Interp *tcl, int argc, char **argv)
 {
-	register HTMLClassData gcd = (HTMLClassData) msg;
+	HTMLClassData gcd = (HTMLClassData) msg;
 	HTMLObject obj = (HTMLObject) gcd->object[gcd->level];
-	register WidgetPrivate wp = &obj->widget;
+	WidgetPrivate wp = &obj->widget;
 	char *text, *format, *font;
 	int pretty = 0;
 
@@ -388,15 +388,11 @@ char **argv;
  * beginning or the end of the document is returned.
  */
 static int 
-htmlPositionToId (msg, tcl, argc, argv)
-MsgContext msg;
-Tcl_Interp *tcl;
-int argc;
-char **argv;
+htmlPositionToId (MsgContext msg, Tcl_Interp *tcl, int argc, char **argv)
 {
-	register HTMLClassData gcd = (HTMLClassData) msg;
+	HTMLClassData gcd = (HTMLClassData) msg;
 	HTMLObject obj = (HTMLObject) gcd->object[gcd->level];
-	register WidgetPrivate wp = &obj->widget;
+	WidgetPrivate wp = &obj->widget;
 	int element_id, x, y;
 	char buf[SZ_NUMBER];
 
@@ -423,15 +419,11 @@ char **argv;
  * the coordinates x,y are undefined.
  */
 static int 
-htmlIdToPosition (msg, tcl, argc, argv)
-MsgContext msg;
-Tcl_Interp *tcl;
-int argc;
-char **argv;
+htmlIdToPosition (MsgContext msg, Tcl_Interp *tcl, int argc, char **argv)
 {
-	register HTMLClassData gcd = (HTMLClassData) msg;
+	HTMLClassData gcd = (HTMLClassData) msg;
 	HTMLObject obj = (HTMLObject) gcd->object[gcd->level];
-	register WidgetPrivate wp = &obj->widget;
+	WidgetPrivate wp = &obj->widget;
 	ObmContext obm = obj->widget.obm;
 	int status, element_id, x, y;
 	char buf[SZ_NUMBER];
@@ -473,15 +465,11 @@ char **argv;
  * coordinates x,y are undefined.
  */
 static int 
-htmlAnchorToPosition (msg, tcl, argc, argv)
-MsgContext msg;
-Tcl_Interp *tcl;
-int argc;
-char **argv;
+htmlAnchorToPosition (MsgContext msg, Tcl_Interp *tcl, int argc, char **argv)
 {
-	register HTMLClassData gcd = (HTMLClassData) msg;
+	HTMLClassData gcd = (HTMLClassData) msg;
 	HTMLObject obj = (HTMLObject) gcd->object[gcd->level];
-	register WidgetPrivate wp = &obj->widget;
+	WidgetPrivate wp = &obj->widget;
 	ObmContext obm = obj->widget.obm;
 	char *anchor, *s_x, *s_y;
 	char buf[SZ_NUMBER];
@@ -522,15 +510,11 @@ char **argv;
  * If there is no anchor with the given name false is returned.
  */
 static int 
-htmlAnchorToId (msg, tcl, argc, argv)
-MsgContext msg;
-Tcl_Interp *tcl;
-int argc;
-char **argv;
+htmlAnchorToId (MsgContext msg, Tcl_Interp *tcl, int argc, char **argv)
 {
-	register HTMLClassData gcd = (HTMLClassData) msg;
+	HTMLClassData gcd = (HTMLClassData) msg;
 	HTMLObject obj = (HTMLObject) gcd->object[gcd->level];
-	register WidgetPrivate wp = &obj->widget;
+	WidgetPrivate wp = &obj->widget;
 	char buf[SZ_NUMBER];
 	int element_id;
 	char *anchor;
@@ -555,15 +539,11 @@ char **argv;
  * An id of zero means go to the top of the document.
  */
 static int 
-htmlGotoId (msg, tcl, argc, argv)
-MsgContext msg;
-Tcl_Interp *tcl;
-int argc;
-char **argv;
+htmlGotoId (MsgContext msg, Tcl_Interp *tcl, int argc, char **argv)
 {
-	register HTMLClassData gcd = (HTMLClassData) msg;
+	HTMLClassData gcd = (HTMLClassData) msg;
 	HTMLObject obj = (HTMLObject) gcd->object[gcd->level];
-	register WidgetPrivate wp = &obj->widget;
+	WidgetPrivate wp = &obj->widget;
 	int element_id;
 
 	if (argc < 2)
@@ -591,11 +571,7 @@ char **argv;
  * anchor in the document being displayed.
  */
 static int 
-htmlGetHRefs (msg, tcl, argc, argv)
-MsgContext msg;
-Tcl_Interp *tcl;
-int argc;
-char **argv;
+htmlGetHRefs (MsgContext msg, Tcl_Interp *tcl, int argc, char **argv)
 {
 	HTMLClassData gcd = (HTMLClassData) msg;
 	HTMLObject obj = (HTMLObject) gcd->object[gcd->level];
@@ -646,11 +622,7 @@ char **argv;
  * A SRC is a HREF pointing to an image file.
  */
 static int 
-htmlGetImageSrcs (msg, tcl, argc, argv)
-MsgContext msg;
-Tcl_Interp *tcl;
-int argc;
-char **argv;
+htmlGetImageSrcs (MsgContext msg, Tcl_Interp *tcl, int argc, char **argv)
 {
 	HTMLClassData gcd = (HTMLClassData) msg;
 	HTMLObject obj = (HTMLObject) gcd->object[gcd->level];
@@ -699,11 +671,7 @@ char **argv;
  * where the structure {{href} {role}} describes each link.
  */
 static int 
-htmlGetLinks (msg, tcl, argc, argv)
-MsgContext msg;
-Tcl_Interp *tcl;
-int argc;
-char **argv;
+htmlGetLinks (MsgContext msg, Tcl_Interp *tcl, int argc, char **argv)
 {
 	HTMLClassData gcd = (HTMLClassData) msg;
 	HTMLObject obj = (HTMLObject) gcd->object[gcd->level];
@@ -720,8 +688,8 @@ char **argv;
 	    a_list = argv[1];
 
 	if ((list = HTMLGetLinks (wp->w, &n))) {
-	    register char *ip, *op;
-	    register int i;
+	    char *ip, *op;
+	    int i;
 
 	    /* Determine how much storage we need for the list. */
 	    for (i=0, nchars=0;  i < n;  i++) {
@@ -774,12 +742,10 @@ char **argv;
  * Tcl list of strings.
  */
 static char *
-makeList (list, n)
-char **list;
-int n;
+makeList (char **list, int n)
 {
-	register char *ip, *op;
-	register int i;
+	char *ip, *op;
+	int i;
 	int nchars;
 	char *buf;
 
@@ -819,15 +785,11 @@ int n;
  * given URL has been visited.
  */
 static int 
-htmlRetestAnchors (msg, tcl, argc, argv)
-MsgContext msg;
-Tcl_Interp *tcl;
-int argc;
-char **argv;
+htmlRetestAnchors (MsgContext msg, Tcl_Interp *tcl, int argc, char **argv)
 {
-	register HTMLClassData gcd = (HTMLClassData) msg;
+	HTMLClassData gcd = (HTMLClassData) msg;
 	HTMLObject obj = (HTMLObject) gcd->object[gcd->level];
-	register WidgetPrivate wp = &obj->widget;
+	WidgetPrivate wp = &obj->widget;
 
 	HTMLRetestAnchors (wp->w, NULL, 0);
 	return (TCL_OK);
@@ -845,15 +807,11 @@ char **argv;
  * that element.
  */
 static int 
-htmlSetSelection (msg, tcl, argc, argv)
-MsgContext msg;
-Tcl_Interp *tcl;
-int argc;
-char **argv;
+htmlSetSelection (MsgContext msg, Tcl_Interp *tcl, int argc, char **argv)
 {
-	register HTMLClassData gcd = (HTMLClassData) msg;
+	HTMLClassData gcd = (HTMLClassData) msg;
 	HTMLObject obj = (HTMLObject) gcd->object[gcd->level];
-	register WidgetPrivate wp = &obj->widget;
+	WidgetPrivate wp = &obj->widget;
 	ElementRef start, end;
 	char *ip = (char *)NULL;
 
@@ -884,15 +842,11 @@ char **argv;
  * An empty string is returned if there is no current text selection.
  */
 static int 
-htmlGetSelection (msg, tcl, argc, argv)
-MsgContext msg;
-Tcl_Interp *tcl;
-int argc;
-char **argv;
+htmlGetSelection (MsgContext msg, Tcl_Interp *tcl, int argc, char **argv)
 {
-	register HTMLClassData gcd = (HTMLClassData) msg;
+	HTMLClassData gcd = (HTMLClassData) msg;
 	HTMLObject obj = (HTMLObject) gcd->object[gcd->level];
-	register WidgetPrivate wp = &obj->widget;
+	WidgetPrivate wp = &obj->widget;
 	char *text, *start, *end, *insert;
 
 	text = HTMLGetTextAndSelection (wp->w, &start, &end, &insert);
@@ -913,15 +867,11 @@ char **argv;
  *  Usage:	clearSelection
  */
 static int 
-htmlClearSelection (msg, tcl, argc, argv)
-MsgContext msg;
-Tcl_Interp *tcl;
-int argc;
-char **argv;
+htmlClearSelection (MsgContext msg, Tcl_Interp *tcl, int argc, char **argv)
 {
-	register HTMLClassData gcd = (HTMLClassData) msg;
+	HTMLClassData gcd = (HTMLClassData) msg;
 	HTMLObject obj = (HTMLObject) gcd->object[gcd->level];
-	register WidgetPrivate wp = &obj->widget;
+	WidgetPrivate wp = &obj->widget;
 
 	HTMLClearSelection (wp->w);
 	return (TCL_OK);
@@ -944,15 +894,11 @@ char **argv;
  *
  */
 static int 
-htmlSearchText (msg, tcl, argc, argv)
-MsgContext msg;
-Tcl_Interp *tcl;
-int argc;
-char **argv;
+htmlSearchText (MsgContext msg, Tcl_Interp *tcl, int argc, char **argv)
 {
-	register HTMLClassData gcd = (HTMLClassData) msg;
+	HTMLClassData gcd = (HTMLClassData) msg;
 	HTMLObject obj = (HTMLObject) gcd->object[gcd->level];
-	register WidgetPrivate wp = &obj->widget;
+	WidgetPrivate wp = &obj->widget;
 	ObmContext obm = obj->widget.obm;
 	char *pattern, *a_start, *a_end;
 	int backward = 0, caseless = 1;
@@ -1033,16 +979,12 @@ retry: 	    start.id = start.pos = 0;
  * selects a new URL while viewing a document.
  */
 static int 
-htmlAddCallback (msg, tcl, argc, argv)
-MsgContext msg;
-Tcl_Interp *tcl;
-int argc;
-char **argv;
+htmlAddCallback (MsgContext msg, Tcl_Interp *tcl, int argc, char **argv)
 {
 	HTMLObject obj = (HTMLObject) msg->object[msg->level];
-	register WidgetPrivate wp = &obj->widget;
-	register HTMLPrivate hp = &obj->html;
-	register Widget w = wp->w;
+	WidgetPrivate wp = &obj->widget;
+	HTMLPrivate hp = &obj->html;
+	Widget w = wp->w;
 	char *userproc, *callback_type;
 	ObmCallback cb, new;
 	int type;
@@ -1082,15 +1024,11 @@ char **argv;
  * named procedure are deleted.
  */
 static int 
-htmlDeleteCallback (msg, tcl, argc, argv)
-MsgContext msg;
-Tcl_Interp *tcl;
-int argc;
-char **argv;
+htmlDeleteCallback (MsgContext msg, Tcl_Interp *tcl, int argc, char **argv)
 {
 	HTMLObject obj = (HTMLObject) msg->object[msg->level];
-	register HTMLPrivate hp = &obj->html;
-	register ObmCallback cb, prev, next;
+	HTMLPrivate hp = &obj->html;
+	ObmCallback cb, prev, next;
 	char *procedure, *callback_type;
 	int type;
 
@@ -1129,14 +1067,11 @@ char **argv;
  * are called in the order in which they were registered.
  */
 static void
-anchorCallback (w, client_data, call_data)
-Widget w;
-XtPointer client_data;
-XtPointer call_data;
+anchorCallback (Widget w, XtPointer client_data, XtPointer call_data)
 {
-	register char *ip, *op;
-	register ObmCallback cb;
-	register WbAnchorCallbackData *ap = (WbAnchorCallbackData *)call_data;
+	char *ip, *op;
+	ObmCallback cb;
+	WbAnchorCallbackData *ap = (WbAnchorCallbackData *)call_data;
 	HTMLObject obj = (HTMLObject) client_data;
 	ObmContext obm = obj->widget.obm;
 	char *text, *href, *none = "none";
@@ -1219,14 +1154,11 @@ XtPointer call_data;
  * has been visited previously, otherwise a zero should be returned.
  */
 static int
-testAnchorCallback (w, client_data, href)
-Widget w;
-XtPointer client_data;
-char *href;
+testAnchorCallback (Widget w, XtPointer client_data, char *href)
 {
-	register ObmCallback cb;
-	register HTMLObject obj = (HTMLObject) client_data;
-	register ObmContext obm = obj->widget.obm;
+	ObmCallback cb;
+	HTMLObject obj = (HTMLObject) client_data;
+	ObmContext obm = obj->widget.obm;
 	int status, retval = 0;
 
 	/* Call any registered callback functions. */
@@ -1273,14 +1205,11 @@ char *href;
  * while "method" is the method to be used to submit the form.
  */
 static void
-submitFormCallback (w, client_data, call_data)
-Widget w;
-XtPointer client_data;
-XtPointer call_data;
+submitFormCallback (Widget w, XtPointer client_data, XtPointer call_data)
 {
-	register char *ip, *op;
-	register ObmCallback cb;
-	register WbFormCallbackData *fp = (WbFormCallbackData *)call_data;
+	char *ip, *op;
+	ObmCallback cb;
+	WbFormCallbackData *fp = (WbFormCallbackData *)call_data;
 	HTMLObject obj = (HTMLObject) client_data;
 	ObmContext obm = obj->widget.obm;
 
@@ -1397,13 +1326,10 @@ XtPointer call_data;
  * are called in the order in which they were registered.
  */
 static void
-linkCallback (w, client_data, call_data)
-Widget w;
-XtPointer client_data;
-XtPointer call_data;
+linkCallback (Widget w, XtPointer client_data, XtPointer call_data)
 {
-	register char *ip, *op;
-	register ObmCallback cb;
+	char *ip, *op;
+	ObmCallback cb;
 	LinkInfo *l_info = (LinkInfo *) call_data;
 	HTMLObject obj = (HTMLObject) client_data;
 	ObmContext obm = obj->widget.obm;
@@ -1440,14 +1366,11 @@ XtPointer call_data;
  *	userproc widget cbtype href
  */
 static void
-pointerMotionCallback (w, client_data, href)
-Widget w;
-XtPointer client_data;
-char *href;
+pointerMotionCallback (Widget w, XtPointer client_data, char *href)
 {
-	register ObmCallback cb;
-	register HTMLObject obj = (HTMLObject) client_data;
-	register ObmContext obm = obj->widget.obm;
+	ObmCallback cb;
+	HTMLObject obj = (HTMLObject) client_data;
+	ObmContext obm = obj->widget.obm;
 	int status;
 
 	/* Call any registered callback functions. */
@@ -1471,11 +1394,9 @@ char *href;
 /* cb_error -- Convenience routine to return an error from a callback.
  */
 static void
-cb_error (obm, cb)
-register ObmContext obm;
-register ObmCallback cb;
+cb_error (ObmContext obm, ObmCallback cb)
 {
-	register Tcl_Interp *tcl = obm->tcl;
+	Tcl_Interp *tcl = obm->tcl;
 	const char *errstr = Tcl_GetVar (tcl, "errorInfo", 0);
 	fprintf (stderr, "Error on line %d in %s: %s\n",
 	    Tcl_GetErrorLine (tcl), cb->name,
@@ -1485,10 +1406,9 @@ register ObmCallback cb;
 /* cb_decode -- Convert a callback_type string to a callback type code.
  */
 static int
-cb_decode (callback_type)
-register char *callback_type;
+cb_decode (char *callback_type)
 {
-	register int type = 0;
+	int type = 0;
 
 	if (strcmp (callback_type, "anchor") == 0)
 	    type = CB_Anchor;
@@ -1507,10 +1427,9 @@ register char *callback_type;
 /* cb_encode -- Convert a callback_type string to a callback type code.
  */
 static char *
-cb_encode (callback_type)
-int callback_type;
+cb_encode (int callback_type)
 {
-	register char *type = "unknown";
+	char *type = "unknown";
 
 	switch (callback_type) {
 	case CB_Anchor:
