@@ -2269,12 +2269,10 @@ struct resource_list {
 /* Prints a table listing the unique resource name/type pairs, with a bitmask
  * indicating the widget classes using each resource/type pair.
  */
-main (argc, argv)
-int	argc;
-char	*argv[];
+main (int argc, char *argv[])
 {
-	register struct resource_list *rp, *np;
-	register unsigned long flags1, flags2;
+	struct resource_list *rp, *np;
+	unsigned long flags1, flags2;
 	int decorate = 0;
 
 	if (argc >= 2 && !strcmp(argv[1],"-decorate"))
