@@ -29,6 +29,7 @@
 
 #include "ptyx.h"
 
+void TabSet(unsigned int *tabs, int col);
 /*
  * This file presumes 32bits/word.  This is somewhat of a crock, and should
  * be fixed sometime.
@@ -37,10 +38,10 @@
 /*
  * places tabstops at only every 8 columns
  */
-TabReset(tabs)
-Tabs	tabs;
+void
+TabReset(unsigned int *tabs)
 {
-	register int i;
+	int i;
 
 	for (i=0; i<TAB_ARRAY_SIZE; ++i)
 		tabs[i] = 0;
@@ -53,9 +54,8 @@ Tabs	tabs;
 /*
  * places a tabstop at col
  */
-TabSet(tabs, col)
-    Tabs	tabs;
-    int		col;
+void
+TabSet(unsigned int *tabs, int col)
 {
 	tabs[col >> 5] |= (1 << (col & 31));
 }
@@ -63,9 +63,8 @@ TabSet(tabs, col)
 /*
  * clears a tabstop at col
  */
-TabClear(tabs, col)
-    Tabs	tabs;
-    int		col;
+void
+TabClear(unsigned int *tabs, int col)
 {
 	tabs[col >> 5] &= ~(1 << (col & 31));
 }
@@ -75,12 +74,11 @@ TabClear(tabs, col)
  * (or MAX_TABS - 1 if there are no more).
  * A tabstop at col is ignored.
  */
-TabNext (tabs, col)
-    Tabs	tabs;
-    int		col;
+int
+TabNext (unsigned int *tabs, int col)
 {
 	extern XgtermWidget term;
-	register TScreen *screen = &term->screen;
+	TScreen *screen = &term->screen;
 
 	if(screen->curses && screen->do_wrap && (term->flags & WRAPAROUND)) {
 		Index(screen, 1);
@@ -96,10 +94,10 @@ TabNext (tabs, col)
 /*
  * clears all tabs
  */
-TabZonk (tabs)
-Tabs	tabs;
+void
+TabZonk (unsigned int *tabs)
 {
-	register int i;
+	int i;
 
 	for (i=0; i<TAB_ARRAY_SIZE; ++i)
 		tabs[i] = 0;
