@@ -2,6 +2,7 @@
  * XIMTOOL.H -- Global definitions for XImtool.
  */
 
+#include <tcl.h>
 #include "../version.h"
 #include "eps.h"
 
@@ -62,7 +63,7 @@
 #define	PRINTCONFIG	   "/usr/local/lib/ximprint.cfg"
 
 #define	DEF_ISM_ADDR	   "/tmp/.ISM%d"	/* default ISM unix socket    */
-#define	DEF_ISM_TEMPLATE   "/tmp/.ISM%d_%d"	/* ISM client socket template */
+#define	DEF_ISM_TEMPLATE   "/tmp/.ISM%d_%lu"	/* ISM client socket template */
 #define DEF_ISM_TASK	   "wcspix"
 #define DEF_ISM_CMD	   "ism_wcspix.e wcspix &"
 /* "/usr/local/bin/ism_wcspix.e wcspix &" */
@@ -315,7 +316,12 @@ typedef struct {
 
 } XimData, *XimDataPtr;
 
-
+/* Client callback struct. */
+typedef struct {
+        XimDataPtr xim;
+        Tcl_Interp *tcl;
+        Tcl_Interp *server;
+} XimClient, *XimClientPtr;
 
 #ifdef XIMTOOL_MAIN
 XimData ximtool_data;
@@ -381,7 +387,7 @@ static XtResource resources[] = {
 	sizeof(int),
 	XtOffsetOf(XimData, def_config),
 	XtRImmediate,
-	(caddr_t)1
+	(void *)1
     },
     {
 	XtNdefNFrames,
@@ -390,7 +396,7 @@ static XtResource resources[] = {
 	sizeof(int),
 	XtOffsetOf(XimData, def_nframes),
 	XtRImmediate,
-	(caddr_t)0
+	(void *)0
     },
     {
 	XtNncolors,
@@ -399,7 +405,7 @@ static XtResource resources[] = {
 	sizeof(int),
 	XtOffsetOf(XimData, ncolors),
 	XtRImmediate,
-	(caddr_t)DEF_NCOLORS
+	(void *)DEF_NCOLORS
     },
     {
 	XtNtileBorderWidth,
@@ -408,7 +414,7 @@ static XtResource resources[] = {
 	sizeof(int),
 	XtOffsetOf(XimData, tileBorder),
 	XtRImmediate,
-	(caddr_t)DEF_TILE_BORDER
+	(void *)DEF_TILE_BORDER
     },
     {
 	XtNtileBorderColor,
@@ -417,7 +423,7 @@ static XtResource resources[] = {
 	sizeof(String),
 	XtOffsetOf(XimData, borderColor),
 	XtRImmediate,
-	(caddr_t)DEF_BORDER_COLOR
+	(void *)DEF_BORDER_COLOR
     },
     {
 	XtNautoscale,
@@ -426,7 +432,7 @@ static XtResource resources[] = {
 	sizeof(Boolean),
 	XtOffsetOf(XimData, autoscale),
 	XtRImmediate,
-	(caddr_t)FALSE
+	(void *)FALSE
     },
     {
 	XtNantialias,
@@ -435,7 +441,7 @@ static XtResource resources[] = {
 	sizeof(Boolean),
 	XtOffsetOf(XimData, antialias),
 	XtRImmediate,
-	(caddr_t)FALSE
+	(void *)FALSE
     },
     {
 	XtNantialiasType,
@@ -444,7 +450,7 @@ static XtResource resources[] = {
 	sizeof(String),
 	XtOffsetOf(XimData, antialiasType),
 	XtRImmediate,
-	(caddr_t)DEF_ANTIALIASTYPE
+	(void *)DEF_ANTIALIASTYPE
     },
     {
 	XtNinvert,
@@ -453,7 +459,7 @@ static XtResource resources[] = {
 	sizeof(Boolean),
 	XtOffsetOf(XimData, invert),
 	XtRImmediate,
-	(caddr_t)FALSE
+	(void *)FALSE
     },
     {
 	XtNtileFrames,
@@ -462,7 +468,7 @@ static XtResource resources[] = {
 	sizeof(Boolean),
 	XtOffsetOf(XimData, tileFrames),
 	XtRImmediate,
-	(caddr_t)FALSE
+	(void *)FALSE
     },
     {
 	XtNhighlightFrames,
@@ -471,7 +477,7 @@ static XtResource resources[] = {
 	sizeof(Boolean),
 	XtOffsetOf(XimData, highlightFrames),
 	XtRImmediate,
-	(caddr_t)TRUE
+	(void *)TRUE
     },
     {
 	XtNcmFocus,
@@ -480,7 +486,7 @@ static XtResource resources[] = {
 	sizeof(int),
 	XtOffsetOf(XimData, cm_focus),
 	XtRImmediate,
-	(caddr_t)512
+	(void *)512
     },
     {
 	XtNgui,
@@ -489,7 +495,7 @@ static XtResource resources[] = {
 	sizeof(String),
 	XtOffsetOf(XimData, gui),
 	XtRImmediate,
-	(caddr_t)"default"
+	(void *)"default"
     },
     {
 	XtNimtoolrc,
@@ -498,7 +504,7 @@ static XtResource resources[] = {
 	sizeof(String),
 	XtOffsetOf(XimData, imtoolrc),
 	XtRImmediate,
-	(caddr_t)FBCONFIG_2
+	(void *)FBCONFIG_2
     },
     {
 	XtNmemModel,
@@ -507,7 +513,7 @@ static XtResource resources[] = {
 	sizeof(String),
 	XtOffsetOf(XimData, memModel),
 	XtRImmediate,
-	(caddr_t)"fast"
+	(void *)"fast"
     },
     {
 	XtNuserCMap1,
@@ -516,7 +522,7 @@ static XtResource resources[] = {
 	sizeof(String),
 	XtOffsetOf(XimData, userCMap1),
 	XtRImmediate,
-	(caddr_t)"none"
+	(void *)"none"
     },
     {
 	XtNuserCMap2,
@@ -525,7 +531,7 @@ static XtResource resources[] = {
 	sizeof(String),
 	XtOffsetOf(XimData, userCMap2),
 	XtRImmediate,
-	(caddr_t)"none"
+	(void *)"none"
     },
     {
 	XtNuserCMapDir1,
@@ -534,7 +540,7 @@ static XtResource resources[] = {
 	sizeof(String),
 	XtOffsetOf(XimData, userCMapDir1),
 	XtRImmediate,
-	(caddr_t)"none"
+	(void *)"none"
     },
     {
 	XtNuserCMapDir2,
@@ -543,7 +549,7 @@ static XtResource resources[] = {
 	sizeof(String),
 	XtOffsetOf(XimData, userCMapDir2),
 	XtRImmediate,
-	(caddr_t)CMAPCONFIG
+	(void *)CMAPCONFIG
     },
     {
 	XtNprintConfig,
@@ -552,7 +558,7 @@ static XtResource resources[] = {
 	sizeof(String),
 	XtOffsetOf(XimData, printConfig),
 	XtRImmediate,
-	(caddr_t)PRINTCONFIG
+	(void *)PRINTCONFIG
     },
     {
 	XtNinput_fifo,
@@ -561,7 +567,7 @@ static XtResource resources[] = {
 	sizeof(String),
 	XtOffsetOf(XimData, input_fifo),
 	XtRImmediate,
-	(caddr_t)O_DEVNAME
+	(void *)O_DEVNAME
     },
     {
 	XtNoutput_fifo,
@@ -570,7 +576,7 @@ static XtResource resources[] = {
 	sizeof(String),
 	XtOffsetOf(XimData, output_fifo),
 	XtRImmediate,
-	(caddr_t)I_DEVNAME
+	(void *)I_DEVNAME
     },
     {
 	XtNunixaddr,
@@ -579,7 +585,7 @@ static XtResource resources[] = {
 	sizeof(String),
 	XtOffsetOf(XimData, unixaddr),
 	XtRImmediate,
-	(caddr_t)DEF_UNIXADDR
+	(void *)DEF_UNIXADDR
     },
     {
 	XtNism_addr,
@@ -588,7 +594,7 @@ static XtResource resources[] = {
 	sizeof(String),
 	XtOffsetOf(XimData, ism_addr),
 	XtRImmediate,
-	(caddr_t)DEF_ISM_ADDR
+	(void *)DEF_ISM_ADDR
     },
     {
 	XtNport,
@@ -597,7 +603,7 @@ static XtResource resources[] = {
 	sizeof(int),
 	XtOffsetOf(XimData, port),
 	XtRImmediate,
-	(caddr_t)DEF_PORT
+	(void *)DEF_PORT
     },
     {
 	XtNnports,
@@ -606,7 +612,7 @@ static XtResource resources[] = {
 	sizeof(int),
 	XtOffsetOf(XimData, nports),
 	XtRImmediate,
-	(caddr_t)DEF_NPORTS
+	(void *)DEF_NPORTS
     },
     {
 	XtNism_task,
@@ -615,7 +621,7 @@ static XtResource resources[] = {
 	sizeof(String),
 	XtOffsetOf(XimData, ism_task),
 	XtRImmediate,
-	(caddr_t)DEF_ISM_TASK
+	(void *)DEF_ISM_TASK
     },
 };
 
@@ -706,55 +712,58 @@ extern Printer printer_list[];
 #define nint(a)		((a)<(0)?((int)(a-0.5)):((int)(a+0.5)))
 #endif
 
-void xim_initialize(), xim_reset(), xim_resize(), xim_refresh();
-int xim_shutdown ();
-void xim_close(), xim_initFrame(), xim_setFrame(), xim_setRop();
-void xim_setReferenceFrame(), xim_setDisplayFrame();
-void xim_delFrame(), xim_setMapping(), xim_setZoom();
-void xim_setCursorPos(), xim_getCursorPos(), xim_setFlip();
-void xim_matchFrames(), xim_registerFrames();
+void xim_initialize(XimDataPtr xim, int config, int nframes, int hardreset), xim_reset(XimDataPtr xim, Widget w), xim_resize(XimDataPtr xim, Widget w), xim_refresh(XimDataPtr xim);
+int xim_shutdown (XimDataPtr xim);
+void xim_close(XimDataPtr xim), xim_initFrame(XimDataPtr xim, int frame, int nframes, FbConfigPtr config, char *memModel), xim_setFrame(XimDataPtr xim, int frame), xim_setRop(XimDataPtr xim, FrameBufPtr fb, int rop);
+void xim_setReferenceFrame(IoChanPtr chan, int frame), xim_setDisplayFrame(XimDataPtr xim, int frame);
+void xim_delFrame(XimDataPtr xim, int frame), xim_setMapping(XimDataPtr xim, FrameBufPtr fb, int frame, int mapping, int src, int dst, int fill_mode);
+void xim_setZoom(XimDataPtr, FrameBufPtr, int, int, int, int, float, float,
+		 float, float, float, float, Boolean);
+void xim_setCursorPos(XimDataPtr, float, float);
+void xim_getCursorPos(XimDataPtr xim, float *sx, float *sy, int *raster, int *frame), xim_setFlip(XimDataPtr xim, FrameBufPtr fb, int flip_x, int flip_y);
+void xim_matchFrames(XimDataPtr xim, int *frames, int reference_frame), xim_registerFrames(XimDataPtr xim, int *frames, int reference_frame, int offsets);
 void xim_readCursor(), xim_frameChanged();
-void xim_message(), xim_msgi(), xim_alert();
-int xim_setColormap();
-int xim_getAntialias();
-char *xim_frameLabel();
-void xim_displayLogo ();
-void xim_initPrinterOps();
-int xim_getPrinterInfo();
-int xim_print();
-void print_mappings();
-void xim_initLoad();
-void xim_scanHeaders();
-void xim_dirRescan();
-int xim_loadFile();
-void xim_loadClose();
+void xim_message(XimDataPtr xim, char *object, char *message), xim_msgi(XimDataPtr xim, char *object, int value), xim_alert(XimDataPtr xim, char *text, char *ok_action, char *cancel_action);
+int xim_setColormap(char *function, String *dirs, short unsigned int *m_red, short unsigned int *m_green, short unsigned int *m_blue, int nelem);
+int xim_getAntialias(XimDataPtr xim, char *s);
+char *xim_frameLabel(XimDataPtr xim);
+void xim_displayLogo (XimDataPtr xim);
+void xim_initPrinterOps(XimDataPtr xim);
+int xim_getPrinterInfo(XimDataPtr xim, char *printer);
+int xim_print(XimDataPtr xim, int x0, int y0, int nx, int ny);
+void print_mappings(FrameBufPtr fr);
+void xim_initLoad(XimDataPtr xim);
+void xim_scanHeaders(XimDataPtr xim);
+void xim_dirRescan(XimDataPtr xim);
+int xim_loadFile(XimDataPtr xim, char *fname, int frame);
+void xim_loadClose(XimDataPtr xim);
 
-int xim_writeDisplay();
-unsigned char *xim_readDisplay();
-void xim_initSave(), xim_closeSave();
-void ximp_rename(), ximp_cancel();
-void xims_rename(), xims_cancel();
-int xim_saveFile();
-void xim_saveClose();
+int xim_writeDisplay(XimDataPtr xim, int frame, char *mapname, unsigned char *pixels, int w, int h, unsigned char *r, unsigned char *g, unsigned char *b, int ncolors);
+unsigned char *xim_readDisplay(XimDataPtr xim, int x0, int y0, int nx, int ny, int *w, int *h, unsigned char *r, unsigned char *g, unsigned char *b, int *ncolors);
+void xim_initSave(XimDataPtr xim), xim_closeSave();
+void ximp_rename(XimDataPtr xim, char *old, char *new), ximp_cancel(XimDataPtr xim, char *fname);
+void xims_rename(XimDataPtr xim, char *old, char *new), xims_cancel(XimDataPtr xim, char *fname);
+int xim_saveFile(XimDataPtr xim, char *template, int fileformat, int x0, int y0, int nx, int ny);
+void xim_saveClose(XimDataPtr xim);
 
-int xim_iisOpen();
-void xim_iisClose(), xim_iisio();
-XtInputId xim_addInput();
-void xim_iisiomap();
-void xim_iiscolormap();
+int xim_iisOpen(XimDataPtr xim);
+void xim_iisClose(XimDataPtr xim), xim_iisio(IoChanPtr chan, int *fd_addr, XtInputId *id_addr);
+XtInputId xim_addInput(XimDataPtr xim, int input, void (*proc) (/* ??? */), XtPointer client_data);
+void xim_iisiomap(XtPointer w, short unsigned int *iomap, int *iomap_len);
+void xim_iiscolormap(XtPointer w, short unsigned int *r, short unsigned int *g, short unsigned int *b, int *first, int *ngray, int *rgb_len);
 
-void xim_removeInput();
-void xim_encodewcs();
-void xim_retCursorVal();
+void xim_removeInput(XimDataPtr xim, XtPointer id);
+void xim_encodewcs(XimDataPtr xim, float sx, float sy, int sz, char *obuf);
+void xim_retCursorVal(XimDataPtr xim, float sx, float sy, int frame, int wcs, int key, char *strval);
 
-void xim_clientOpen(), xim_clientClose();
-int xim_clientExecute();
-void xim_ismOpen(), xim_ismClose();
-void xim_enhancement();
-void xim_eraseFrame();
-void xim_tileFrames();
-void xim_fitFrame();
-void xim_cursorMode();
+void xim_clientOpen(XimDataPtr xim), xim_clientClose(XimDataPtr xim);
+int xim_clientExecute(XimClientPtr xc, Tcl_Interp *tcl, char *objname, int key, char *command);
+void xim_ismOpen(XimDataPtr xim), xim_ismClose(XimDataPtr xim);
+void xim_enhancement(XimDataPtr xim, FrameBufPtr fb);
+void xim_eraseFrame(XimDataPtr xim, int frame);
+void xim_tileFrames(XimDataPtr xim, int frame_list);
+void xim_fitFrame(XimDataPtr xim);
+void xim_cursorMode(XimDataPtr xim, int state);
 
-int ism_message();
-void wcspix_message();
+void ism_message(XimDataPtr xim, char *object, char *command);
+void wcspix_message(XimDataPtr xim, char *message);
